/***************************************************************
 * Name:      wx010Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-29
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx010Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx010Frame, wxFrame)
    EVT_CLOSE(wx010Frame::OnClose)
    EVT_MENU(idMenuQuit, wx010Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx010Frame::OnAbout)
    EVT_MENU(idMenuGauge, wx010Frame::OnGauge)
END_EVENT_TABLE()

wx010Frame::wx010Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuGauge, _T("&Barras de progreso"), _T("Barras de progreso"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);

}

wx010Frame::~wx010Frame()
{
}

void wx010Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx010Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx010Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a ..."));
}

void wx010Frame::OnGauge(wxCommandEvent& event)
{
    gauge *dlg = new gauge(this);
    dlg->ShowModal();
}
